Cloverage custom reporter that generates Cobertura XML coverage reports.
Usage (CLI): lein cloverage --custom-report cloverage.coverage.cobertura/report
Usage (project.clj): :cloverage {:custom-report cloverage.coverage.cobertura/report}
Writes 'cobertura.xml' to the cloverage output directory (default: target/coverage/).
The Cobertura XML schema maps Clojure namespaces to packages and classes:
Cloverage custom reporter that generates Cobertura XML coverage reports.
Usage (CLI):
lein cloverage --custom-report cloverage.coverage.cobertura/report
Usage (project.clj):
:cloverage {:custom-report cloverage.coverage.cobertura/report}
Writes 'cobertura.xml' to the cloverage output directory (default: target/coverage/).
The Cobertura XML schema maps Clojure namespaces to packages and classes:
- Package: all but the last segment of the namespace (e.g. 'example.util' -> 'example')
- Class: the full namespace string (e.g. 'example.util')
- File: the source path relative to the project root(report {:keys [output forms args]})Generate a Cobertura XML coverage report.
Invoked by cloverage at the end of a coverage run via: --custom-report cloverage.coverage.cobertura/report
Receives a map with: :output - output directory path (String) :forms - raw coverage forms collection :args - parsed cloverage CLI options :project - Leiningen project map
Generate a Cobertura XML coverage report. Invoked by cloverage at the end of a coverage run via: --custom-report cloverage.coverage.cobertura/report Receives a map with: :output - output directory path (String) :forms - raw coverage forms collection :args - parsed cloverage CLI options :project - Leiningen project map
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |